@@ -4,5 +4,5 @@ from enum import Enum, unique
 @unique
 class EnumFutureType(Enum):
     Normal = 0
-    Index = 1,
+    Index = 1
     Reference = 2
